require 'uu/os/http/http_request'
require 'uu/os/util/response_builder'

module UU
  module OS
    module Server

      # Ancestor of all servlets (low-level components allowing to process
      # incoming request and provide custom response without direct dependency
      # on particular server implementation).
      class AbstractServlet
        include UU::OS::Util::ResponseBuilder

        # Main method for processing requests. Response should be built using
        # methods {#response}, {#file_download_response} or {#streamed_response}.
        # @param [UU::OS::HTTP::HTTPRequest] request Incoming request.
        # @return [Object] Response provided by {#response}, {#file_download_response}
        #    or {#streamed_response} methods.
        # @note Method must be implemented in each servlet inherited from this class!
        # @private
        def service(request) # :nodoc:
          raise NotImplementedError, "method not implemented for #{self.class}"
        end

      end

    end
  end
end
